import { ReactWidget } from '@jupyterlab/apputils';
import React from 'react';
import { CommandIDs } from '../commands';
const TENSORBOARD_CLASS = 'jp-Tensorboard';
const TENSORBOARD_ICON_CLASS = 'jp-Tensorboards-itemIcon';
import { TensorboardTabReact } from './tab';
/**
 * A Counter Lumino Widget that wraps a CounterComponent.
 */
export class TensorboardTabReactWidget extends ReactWidget {
    /**
     * Constructs a new CounterWidget.
     */
    constructor(options) {
        super();
        this.currentTensorBoardModel = null;
        this.closeCurrent = () => {
            this.dispose();
            this.close();
        };
        this.updateCurrentModel = (model) => {
            this.currentTensorBoardModel = model;
        };
        this.getCWD = () => {
            return this.browserFactory.defaultBrowser.model.path;
        };
        this.openTensorBoard = (modelName, copy) => {
            this.app.commands.execute(CommandIDs.open, {
                modelName,
                copy
            });
        };
        this.openDoc = () => {
            this.app.commands.execute(CommandIDs.openDoc);
        };
        this.browserFactory = options.browserFactory;
        this.tensorboardManager = options.tensorboardManager;
        this.createdModelName = options.createdModelName;
        this.app = options.app;
        this.addClass('tensorboard-ng-widget');
        this.addClass(TENSORBOARD_CLASS);
        this.title.label = 'TensorBoard';
        this.title.icon = TENSORBOARD_ICON_CLASS;
        this.title.closable = true;
        const caption = 'Name: TensorBoard';
        this.title.caption = caption;
    }
    /**
     * Dispose of the resources held by the tensorboard widget.
     */
    dispose() {
        super.dispose();
    }
    onCloseRequest(msg) {
        super.onCloseRequest(msg);
        this.dispose();
    }
    render() {
        return (React.createElement(TensorboardTabReact, { update: this.update.bind(this), updateCurrentModel: this.updateCurrentModel, tensorboardManager: this.tensorboardManager, getCWD: this.getCWD, openTensorBoard: this.openTensorBoard, closeWidget: this.closeCurrent, openDoc: this.openDoc, createdModelName: this.createdModelName }));
    }
}
